## 港股交易日历

接口：hk_tradecal

描述：获取交易日历

限量：单次最大2000

权限：用户积累2000积分才可调取

输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| start_date | str | N | 开始日期 |
| end_date | str | N | 结束日期 |
| is_open | str | N | 是否交易 '0'休市 '1'交易 |

输出参数

| 名称 | 类型 | 默认显示 | 描述 |
| --- | --- | --- | --- |
| cal_date | str | Y | 日历日期 |
| is_open | int | Y | 是否交易 '0'休市 '1'交易 |
| pretrade_date | str | Y | 上一个交易日 |

接口示例

```python
pro = ts.pro_api()

df = pro.hk_tradecal(start_date='20200101', end_date='20200708')
```

数据示例

```python
cal_date     is_open pretrade_date
    0  20200708        1      20200707
```